### Volume 6, Issue 3, 01 February 1965

- ##### INFRARED LASER ACTION AND LIFETIMES IN ARGON II

  F. A. Horrigan, S. H. Koozekanani and R. A. Paananen
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6 , 41 (1965) ; http://dx.doi.org/10.1063/1.1754155
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### LASER ACTION IN URANYL‐SENSITIZED Nd‐DOPED GLASS

  N. T. Melamed, C. Hirayama and P. W. French
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6 , 43 (1965) ; http://dx.doi.org/10.1063/1.1754156
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### Yb3+–Er3+ GLASS LASER

  E. Snitzer and R. Woodcock
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6 , 45 (1965) ; http://dx.doi.org/10.1063/1.1754157
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### ENERGY TRANSFER IN TRIPLY ACTIVATED GLASSES

  H. W. Gandy, R. J. Ginther and J. F. Weller
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6 , 46 (1965) ; http://dx.doi.org/10.1063/1.1754158
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### STAGE I RECOVERY OF DEFORMED ZIRCONIUM

  M. L. Swanson, A. F. Quenneville and H. Schultz
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6 , 49 (1965) ; http://dx.doi.org/10.1063/1.1754159
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### PROPAGATION OF LONGITUDINAL PLASMA OSCILLATIONS NEAR CYCLOTRON HARMONICS

  By R. S. Harp
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6 , 51 (1965) ; http://dx.doi.org/10.1063/1.1754160
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### AN ANALYTIC FORM OF KU AND ULLMANS EQUATIONS

  By John G. Simmons
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6 , 54 (1965) ; http://dx.doi.org/10.1063/1.1754161
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### A NEW PRINCIPLE FOR THE CONSTRUCTION OF STABILIZED SUPERCONDUCTING COILS

  A. R. Kantrowitz and Z. J. J. Stekly
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6 , 56 (1965) ; http://dx.doi.org/10.1063/1.1754162
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### CATHODOLUMINESCENCE OF THIN FILMS CONTAINING RARE‐EARTH OXIDES

  W. W. Hansen and R. E. Myers
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6 , 58 (1965) ; http://dx.doi.org/10.1063/1.1754163
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this

- ##### LONGITUDINAL INJECTION‐PLASMA LASER OF InSb

  By Ivars Melngailis
  Scitation Author Page
  PubMed
  Google Scholar
  Source: Appl. Phys. Lett. 6 , 59 (1965) ; http://dx.doi.org/10.1063/1.1754164
  View Description Hide Description
  - Add to my favorites
  - Export citation
    - BibTEX
    - EndNote
    - Plain text
    - RefWorks
  - Email this